@@ -34,7 +34,7 @@
 /*
  * cert.h - public data structures and prototypes for the certificate library
  *
- * $Id: cert.h,v 1.8.2.1 2001/03/26 23:18:32 relyea%netscape.com Exp $
+ * $Id: cert.h,v 1.12 2001/06/21 03:20:09 nelsonb%netscape.com Exp $
  */
 
 #ifndef _CERT_H_
@@ -524,7 +524,7 @@ extern void CERT_ClosePermCertDB(CERTCertDBHandle *handle);
 **		been overridden by the user.
 */
 extern SECCertTimeValidity CERT_CheckCertValidTimes(CERTCertificate *cert,
-						    int64 t,
+						    PRTime t,
 						    PRBool allowOverride);
 
 /*
@@ -544,7 +544,7 @@ extern SECStatus CERT_CertTimesValid(CERTCertificate *cert);
 **	"notAfter" is the end of the validity period
 */
 extern SECStatus
-CERT_GetCertTimes (CERTCertificate *c, int64 *notBefore, int64 *notAfter);
+CERT_GetCertTimes (CERTCertificate *c, PRTime *notBefore, PRTime *notAfter);
 
 /*
 ** Extract the issuer and serial number from a certificate
@@ -614,7 +614,7 @@ CERT_ImportCAChain (SECItem *certs, int numcerts, SECCertUsage certUsage);
 **	"f" is the callback function
 **	"arg" is the callback argument
 */
-typedef SECStatus (*CERTImportCertificateFunc)
+typedef SECStatus (PR_CALLBACK *CERTImportCertificateFunc)
    (void *arg, SECItem **certs, int numcerts);
 
 extern SECStatus
@@ -996,6 +996,9 @@ CERT_MakeCANickname(CERTCertificate *cert);
 PRBool
 CERT_IsCACert(CERTCertificate *cert, unsigned int *rettype);
 
+PRBool
+CERT_IsCADERCert(SECItem *derCert, unsigned int *rettype);
+
 SECStatus
 CERT_SaveSMimeProfile(CERTCertificate *cert, SECItem *emailProfile,
 		      SECItem *profileTime);
